summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoSearchDia.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoSearchDia.cpp')
-rw-r--r--lib/kotext/KoSearchDia.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/lib/kotext/KoSearchDia.cpp b/lib/kotext/KoSearchDia.cpp
index 955b3f1c..a41de932 100644
--- a/lib/kotext/KoSearchDia.cpp
+++ b/lib/kotext/KoSearchDia.cpp
@@ -39,7 +39,7 @@
#include <tqradiobutton.h>
#include <tqregexp.h>
#include <tqspinbox.h>
-#include <layout.h>
+#include <tqlayout.h>
KoSearchContext::KoSearchContext()
{
@@ -382,8 +382,8 @@ void KoFindReplace::replace( const TQString &text, int matchingIndex,
{
replaceWithAttribut( &cursor, index );
}
- // Don't repaint if we're doing batch changes
- bool repaint = options() & KReplaceDialog::PromptOnReplace;
+ // Don't tqrepaint if we're doing batch changes
+ bool tqrepaint = options() & KReplaceDialog::PromptOnReplace;
// Grab replacement string
TQString rep = text.mid( matchingIndex, replacementLength );
@@ -395,7 +395,7 @@ void KoFindReplace::replace( const TQString &text, int matchingIndex,
KCommand *cmd = currentTextObj->replaceSelectionCommand(
&cursor, rep, TQString(),
KoTextDocument::HighlightSelection,
- repaint ? KoTextObject::DefaultInsertFlags : KoTextObject::DoNotRepaint );
+ tqrepaint ? KoTextObject::DefaultInsertFlags : KoTextObject::DoNotRepaint );
connect( &m_textIterator, TQT_SIGNAL( currentParagraphModified( int, int, int ) ),
this, TQT_SLOT( slotCurrentParagraphModified( int, int, int ) ) );
@@ -587,7 +587,7 @@ KoFormatDia::KoFormatDia( TQWidget* parent, const TQString & _caption, KoSearchC
m_languageItem->setCurrentText( KoGlobal::languageFromTag( m_ctx->m_language ) );
- m_checkVertAlign = new TQCheckBox( i18n( "Vertical alignment:" ), page );
+ m_checkVertAlign = new TQCheckBox( i18n( "Vertical tqalignment:" ), page );
m_familyItem = new KFontCombo(page);
m_familyItem->setCurrentFont(m_ctx->m_family);
@@ -605,25 +605,25 @@ KoFormatDia::KoFormatDia( TQWidget* parent, const TQString & _caption, KoSearchC
TQButtonGroup *grpBold = new TQButtonGroup( 1, Qt::Vertical, page );
grpBold->setRadioButtonExclusive( TRUE );
- grpBold->layout();
+ grpBold->tqlayout();
m_boldYes=new TQRadioButton( i18n("Yes"), grpBold );
m_boldNo=new TQRadioButton( i18n("No"), grpBold );
TQButtonGroup *grpItalic = new TQButtonGroup( 1, Qt::Vertical, page );
grpItalic->setRadioButtonExclusive( TRUE );
- grpItalic->layout();
+ grpItalic->tqlayout();
m_italicYes=new TQRadioButton( i18n("Yes"), grpItalic );
m_italicNo=new TQRadioButton( i18n("No"), grpItalic );
TQButtonGroup *grpShadow = new TQButtonGroup( 1, Qt::Vertical, page );
grpShadow->setRadioButtonExclusive( TRUE );
- grpShadow->layout();
+ grpShadow->tqlayout();
m_shadowYes=new TQRadioButton( i18n("Yes"), grpShadow );
m_shadowNo=new TQRadioButton( i18n("No"), grpShadow );
TQButtonGroup *grpWordByWord = new TQButtonGroup( 1, Qt::Vertical, page );
grpWordByWord->setRadioButtonExclusive( TRUE );
- grpWordByWord->layout();
+ grpWordByWord->tqlayout();
m_wordByWordYes=new TQRadioButton( i18n("Yes"), grpWordByWord );
m_wordByWordNo=new TQRadioButton( i18n("No"), grpWordByWord );